<?php
/*
 * @file skos_explorer.theme.inc
 *
 *
 * Include all theme helper functions
 */

/**
 * Replace drupal standard markup for form label
 *
 * Alters theme registry functions
 * for form elements label
 *
 * @see theme_form_element_label()
 */
function skos_explorer_form_element_label($variables) {
  $element = $variables['element'];
  // This is also used in the installer, pre-database setup.
  $t = get_t();

  // If title and required marker are both empty, output no label.
  if (empty($element['#title']) && empty($element['#required'])) {
    return '';
  }

  // If the element is required, a required marker is appended to the label.
  $required = !empty($element['#required']) ? theme('form_required_marker', array('element' => $element)) : '';

  $title = filter_xss_admin($element['#title']);

  $attributes = array();
  if ($element['#title_display'] == 'invisible') {
    $attributes['class'] = 'option';
  }

  if (!empty($element['#id'])) {
    $attributes['for'] = $element['#id'];
  }

  // The leading whitespace helps visually separate fields from inline labels.
  return ' <label' . drupal_attributes($attributes) . '>' . $t('!title !required', array('!title' => $title, '!required' => $required)) . "</label>\n";
}

function  skos_explorer_form_element($variables) {
  $element = &$variables['element'];
  // This is also used in the installer, pre-database setup.
  $t = get_t();

  // This function is invoked as theme wrapper, but the rendered form element
  // may not necessarily have been processed by form_builder().
  $element += array(
    '#title_display' => 'before',
  );

  // Add element #id for #type 'item'.
  if (isset($element['#markup']) && !empty($element['#id'])) {
    $attributes['id'] = $element['#id'];
  }
  // Add element's #type and #name as class to aid with JS/CSS selectors.
  $attributes['class'] = array('form-item');
  if (!empty($element['#type'])) {
    $attributes['class'][] = 'form-type-' . strtr($element['#type'], '_', '-');
  }
  if (!empty($element['#name'])) {
    $attributes['class'][] = 'form-item-' . strtr($element['#name'], array(' ' => '-', '_' => '-', '[' => '-', ']' => ''));
  }
  // Add a class for disabled elements to facilitate cross-browser styling.
  if (!empty($element['#attributes']['disabled'])) {
    $attributes['class'][] = 'form-disabled';
  }
  //$output = '<div' . drupal_attributes($attributes) . '>' . "\n";
  $output = '';
  // If #title is not set, we don't display any label or required marker.
  if (!isset($element['#title'])) {
    $element['#title_display'] = 'none';
  }
  $prefix = isset($element['#field_prefix']) ? '<span class="field-prefix">' . $element['#field_prefix'] . '</span> ' : '';
  $suffix = isset($element['#field_suffix']) ? ' <span class="field-suffix">' . $element['#field_suffix'] . '</span>' : '';

  switch ($element['#title_display']) {
    case 'before':
      $output .= ' ' . theme('form_element_label', $variables);
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;
    case 'invisible':
    case 'after':
      $output .= ' ' . $prefix . $element['#children'] . $suffix;
      $output .= ' ' . theme('form_element_label', $variables) . "\n";
      break;

    case 'none':
    case 'attribute':
      // Output no label and no required marker, only the children.
      $output .= ' ' . $prefix . $element['#children'] . $suffix . "\n";
      break;
  }

  if (!empty($element['#description'])) {
    $output .= '<div class="description">' . $element['#description'] . "</div>\n";
  }

  //$output .= "</div>\n";

  return $output;

}

/**
 * Give drupal the ability to format definition lists
 *
 * Custom formatting function to
 * make drupal capable to output
 * definition lists
 *
 * @see theme_item_list()
 */
function skos_explorer_definition_list($variables) {
  $items = $variables['items'];
  $title = $variables['title'];
  $attributes = $variables['attributes'];

  $output = '<div class="definition-list">';
  if (isset($title)) {
    $output .= '<h3>' . $title . '</h3>';
  }

  if (!empty($items)) {
    $output .= '<dl' . drupal_attributes($attributes) . '>';
    foreach ($items as $term => $item) {
      // get definition(s) and attributes for current term (and possibly an override for the term)
      $definitions = array();
      $attributes = array();
      if (is_array($item)) {
        foreach ($item as $key => $value) {
          if ($key === 'term') {
            $term = $value;
          }
          elseif ($key === 'attributes') {
            $attributes = $value;
          }
          else {
            $definitions[] = $value;
          }
        }
      }
      else {
        $definitions[] = $item;
      }
      // output definition term
      $output .= '<dt' . drupal_attributes($attributes) . '>' . $term . '</dt>';
      // iterate over definition(s)
      foreach ($definitions as $definition) {
        if (is_array($definition)) {
          // complex definition item: get data, attributes and children
          $data = $definition['data'];
          $attributes = (array)($definition['attributes']);
          if (isset($definition['children'])) {
            $data .= skos_explorer_definition_list($definition['children'], NULL, $attributes);
          }
          $output .= '<dd' . drupal_attributes($attributes) . '>' . $data . '</dd>';
        }
        else {
          // simple definition item
          $output .= '<dd>' . $definition . '</dd>';
        }
      }
    }
    $output .= '</dl>';
  }
  $output .= '</div>';
  return $output;
}
